@@ -216,7 +216,7 @@ static gboolean launch_me(t_tl *tl, gboolean check_only)
 		}
 		/*xfce_info("%X: %d", file, state);*/
 		
-		fclose(file);
+		pclose(file);
 		signal(SIGPIPE, SIG_DFL);
 		
 		return (state ? TRUE : FALSE);
